=======
Friture
=======

**Friture** is an application to visualize and analyze live audio data in real-time.

Friture displays audio data in several widgets, such as a scope, a spectrum analyzer, or a rolling 2D spectrogram.

This program can be useful to analyze and equalize the audio response of a hall, or for educational purposes, etc.

The name *Friture* is a french word for *frying*, also used for *noise* in a sound.

See the `project homepage`_ for screenshots and more information.

.. _`project homepage`: http://tlecomte.github.com/friture/
